==> qtjambi-uic-5.15.17-sources.jar: io/qt/uic/ui4/DomChar.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomChar</code></p>
 */
public class DomChar extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomChar::<wbr>DomChar()</code></p>
     */
    public DomChar(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomChar instance);
    
    /**
     * <p>See <code>DomChar::<wbr>clearElementUnicode()</code></p>
     */
    @QtUninvokable
    public final void clearElementUnicode(){
        clearElementUnicode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementUnicode_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomChar::<wbr>elementUnicode()const</code></p>
     */
    @QtUninvokable
    public final int elementUnicode(){
        return elementUnicode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementUnicode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomChar::<wbr>hasElementUnicode()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementUnicode(){
        return hasElementUnicode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementUnicode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomChar::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomChar::<wbr>setElementUnicode(int)</code></p>
     */
    @QtUninvokable
    public final void setElementUnicode(int a){
        setElementUnicode_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementUnicode_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomChar::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomChar(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomChar.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomChar</code></p>
 */
public class DomChar extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomChar::<wbr/>DomChar()</code></p>
     */
    public DomChar(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomChar instance);
    
    /**
     * <p>See <code>DomChar::<wbr/>clearElementUnicode()</code></p>
     */
    @QtUninvokable
    public final void clearElementUnicode(){
        clearElementUnicode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementUnicode_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomChar::<wbr/>elementUnicode()const</code></p>
     */
    @QtUninvokable
    public final int elementUnicode(){
        return elementUnicode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementUnicode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomChar::<wbr/>hasElementUnicode()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementUnicode(){
        return hasElementUnicode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementUnicode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomChar::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomChar::<wbr/>setElementUnicode(int)</code></p>
     */
    @QtUninvokable
    public final void setElementUnicode(int a){
        setElementUnicode_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementUnicode_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomChar::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomChar(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
